<?php
// vim:filetype=php expandtab tabstop=2 softtabstop=2 shiftwidth=2 autoindent smartindent
// $Id: tribune.page.inc,v 1.1.2.2 2009/03/03 22:12:35 seeschloss Exp $

function tribune_page() {

  if (user_access("access tribune rss feed")) {
    drupal_add_feed(url("tribune.rss"));
  }

  drupal_add_css(drupal_get_path('module', 'tribune') .'/css/tribune.page.css');

  $history_size   = variable_get("tribune_history_size", 25);
  $reload_delay   = variable_get("tribune_reload_delay", 30) * 1000; // in milliseconds
  $idle_delay     = variable_get("tribune_idle_delay",    0) * 1000; // in milliseconds
  $number_posts   = $history_size;
  $last_load_time = time();

  $tribune_id = "tribune-page";

  drupal_add_js(
    array(
      "tribune" => array(
        "tribunes" => array(
          $tribune_id => array(
            "history_size"   => $history_size,
            "reload_delay"   => $reload_delay,
            "idle_delay"     => $idle_delay,
            "last_load_time" => $last_load_time,
            "message_order"  => variable_get('tribune_order', 'top_to_bottom'),
            "block" => FALSE,
            "path" => array(
              "post" => url("tribune/post"),
              "json_post" => url("tribune/post-json"),
              "json_posts" => url("tribune/newposts-json"),
              "filters" => url("tribune/filter"),
            ),
          ),
        ),
      ),
    ), "setting"
  );

  drupal_add_js(drupal_get_path('module', 'tribune') .'/js/tribune.ajax.js');
  drupal_add_js('misc/jquery.form.js');

  if (variable_get('tribune_pager', FALSE)) {
    $posts = array();

    $r = pager_query("SELECT *
                      FROM {tribune}
                      ORDER BY post_id DESC",
                     variable_get('tribune_history_size', 25),
                     0,
                     NULL,
                     array());

    while ($row = db_fetch_array($r)) {
      $posts[$row['post_id']] = tribune_post_from_row($row);
    }
    $posts = array_reverse($posts, true);
    return theme("tribune_page", $posts, $tribune_id).theme("pager", array(), variable_get('tribune_history_size', 25));
  } else {
    $posts = get_last_posts(variable_get('tribune_history_size', 25));
    return theme("tribune_page", $posts, $tribune_id);
  }
}

/**
  * Show cookie information for Coincoin users
  */
function tribune_show_info() {
  $user   = user_load_self(array());
  $logged = strlen($user[1]->name) > 0;

  $cookie  = "";
  $content = "";

  if ($logged) {

    if (isset ($_SERVER['HTTP_COOKIE'])) {
      //$cookie = explode(';',  $_SERVER['HTTP_COOKIE']);
      //$cookie = $cookie[0];

      $cookie = $_SERVER['HTTP_COOKIE'];
    }

    $content = t("<p><strong>Your cookie</strong>: @cookie</p>", array('@cookie' => $cookie));
  }

  $site_root = url(NULL, array('absolute' => TRUE));

  $url_backend = url("tribune.xml", array('absolute' => TRUE));
  $url_post  = url("tribune/post", array('absolute' => TRUE));
  $url_b2b   = url("tribune/info/b2b.xml", array('absolute' => TRUE));

  $content .= "<p><strong>Backend</strong>: ". $url_backend ."</p>";
  $content .= "<p><strong>Post URL</strong>: ". $url_post ."</p>";
  $content .= "<p><strong>B2B discover URL</strong> (for ". l("JCoinCoin", "http://fredm00.free.fr/jcoincoin/") ."): ". $url_b2b ."</p>";

  $login = $logged ? $user[1]->name : t("YOUR_LOGIN");

  $wmcc_conf .= "board_site:                \"". variable_get("tribune_name", variable_get("site_name", "")) ."\"\n";
  $wmcc_conf .= ".backend_flavour:          2\n";
  $wmcc_conf .= ".palmipede.userlogin:      ". $login ."\n";
  $wmcc_conf .= ".backend.url:              ". $url_backend ."\n";
  $wmcc_conf .= ".post.url:                 ". $url_post ."\n";
  $wmcc_conf .= ".tribune.delay:            ". variable_get("tribune_reload_delay", 30) ."\n";
  $wmcc_conf .= ".palmipede.msg_max_length: ". variable_get("tribune_max_message_size", 512) ."\n";
  if ($logged) {
    $wmcc_conf .= "\n";
    $wmcc_conf .= "\"". variable_get("tribune_name", variable_get("site_name", "")) ."\" cookie: \"". $cookie ."\"\n";
  }

  $content .= t("<div>For <strong><a href='http://hules.free.fr/wmcoincoin'>wmcoincoin</a> users, wmc&sup2; configuration</strong> (place it in <code>~/.wmcoincoin/options</code>):");
  $content .= "<pre>". $wmcc_conf ."</pre>";
  $content .= "</div>";

  //$cscs_conf  = "[".check_plain(variable_get("tribune_name", variable_get("site_name", "")))."]\n";
  $cscs_conf  = "[dlfp]\n";
  $cscs_conf .= "serveur = ". substr($site_root, 7, strlen($site_root) - 8) ."\n";
  $cscs_conf .= "derriere_end = /tribune.xml\n";
  $cscs_conf .= "post_url = /tribune/post\n";
  $cscs_conf .= "format = message=%m\n";
  $cscs_conf .= "pseudo = ". $login ."\n";
  $cscs_conf .= "cookie = ". str_replace(";", "<point-virgule>", $cookie) ."\n";
  $cscs_conf .= "riload = ". variable_get("tribune_reload_delay", 30) ."\n";
  $cscs_conf .= "max = ". variable_get("tribune_max_message_size", 512) ."\n";
  $cscs_conf .= "slip = tags_encodes\n";
  $cscs_conf .= "UTF = True\n";
  $cscs_conf .= "proxy = \n";
  $cscs_conf .= "proxyUser = \n";
  $cscs_conf .= "proxyPass = \n";

  $content .= t("<div>For <strong><a href='http://seeschloss.org/coin.html'>C#oinC#oin</a> users, c#&sup2; configuration</strong> (place it in <code>coin.ini</code>):");
  $content .= "<pre>". $cscs_conf ."</pre>";
  $content .= "</div>";

  return $content;
}

